% ---------------------------------------------------------------------
% Conference proceedings and article templates for
% personal open-archiving activities
% September 2012
% ---------------------------------------------------------------------

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{SelfArx}[25/01/2012, v1.0]
\RequirePackage{ifthen}
\RequirePackage{calc}
\AtEndOfClass{\RequirePackage{microtype}}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions*
\LoadClass{article}

%\RequirePackage{txfonts}      % Loads the Times-Roman Fonts
%\gdef\ttdefault{cmtt}%
   %\let\iint\relax
  %\let\iiint\relax
  %\let\iiiint\relax
  %\let\idotsint\relax
%  \let\openbox\relax
%\RequirePackage{mathptmx}   % Loads the Times-Roman Math Fonts
\RequirePackage{ifpdf}      % Needed to pick between latex and pdflatex

% ---------------------------------------------------------------------
\RequirePackage[utf8]{inputenc}
\RequirePackage{amsmath}
\RequirePackage{graphicx,xcolor}
\RequirePackage[english]{babel}
\RequirePackage{booktabs}
% ---------------------------------------------------------------------

%%%%% for abstract+authors frames 


% ---------------------------------------------------------------------		  
% margins		  
\RequirePackage{geometry}%
 \geometry{paperwidth=210mm,
  paperheight=297mm,
  top=2.25cm,
  bottom=3.25cm,
  textwidth=440pt,
  centering,
  headheight=12pt,
  headsep=12pt,
  footskip=60pt,
  %footnotesep=24pt plus 2pt minus 12pt,
 }
\RequirePackage[labelfont={bf,footnotesize,sf},font={small},labelsep=period]{caption}
% ---------------------------------------------------------------------
\RequirePackage{fancyhdr}  % Needed to define custom headers/footers
%\RequirePackage{lastpage}  % Number of pages in the document
\pagestyle{fancy}          % Enables the custom headers/footers
% Headers
\lhead{}%
\chead{}%
\rhead{}
% Footers
\lfoot{}%
\cfoot{\thepage}%
\rfoot{}%
\renewcommand{\headrulewidth}{0pt}% % No header rule
\renewcommand{\footrulewidth}{0pt}% % No footer rule
% ---------------------------------------------------------------------
% section/subsection/paragraph set-up
\RequirePackage[explicit]{titlesec}
\titleformat{\section}
  {\large\bfseries\sffamily}
  {\thesection.}
  {0.5em}
  {#1}
  []
\titleformat{name=\section,numberless}
  {\large\bfseries\sffamily}
  {}
  {0em}
  {#1}
  []  
\titleformat{\subsection}
  {\bfseries\sffamily}
  {\thesubsection}
  {0.5em}
  {#1}
  []
\titleformat{\subsubsection}
  {\bfseries\sffamily\small}
  {\thesubsubsection}
  {0.5em}
  {#1}
  []    
\titleformat{\paragraph}[runin]
  {\sffamily\small\bfseries}
  {}
  {0em}
  {#1} 
\titlespacing*{\section}{0pc}{3ex \@plus4pt \@minus3pt}{5pt}
\titlespacing*{\subsection}{0pc}{2.5ex \@plus3pt \@minus2pt}{2pt}
\titlespacing*{\subsubsection}{0pc}{2ex \@plus2.5pt \@minus1.5pt}{2pt}
\titlespacing*{\paragraph}{0pc}{1.5ex \@plus2pt \@minus1pt}{10pt}
% ---------------------------------------------------------------------
% tableofcontents set-up
\setcounter{tocdepth}{2}%
\newlength\tocsep%
\setlength{\tocsep}{.3cm}%
\usepackage{titletoc}%
\contentsmargin{0cm}%
\titlecontents{section}[\tocsep]%
  {\addvspace{2pt}\scriptsize\bfseries\sffamily}%
  {\color{color1}\contentslabel[\thecontentslabel]{\tocsep}}%
  {}%
  {\color{color1}\ \titlerule*[.5pc]{.}\ \thecontentspage}%
  []%
\titlecontents*{subsection}[\tocsep]%
  {\addvspace{0pt}\scriptsize\sffamily}%
  {}%
  %{\contentslabel[\thecontentslabel]{\tocsep}}
  {}%
  %{\ \titlerule*[.5pc]{.}\ \thecontentspage}
  {}%
  [\color{color1}\;\textbullet\;]%
\titlecontents*{subsubsection}[\tocsep]%
  {\footnotesize\sffamily}%
  {}%
  {}%
  {}%
  [\textbullet]%
\titlecontents*{paragraph}[\tocsep]%
  {\footnotesize\sffamily}%
  {}%
  {}%
  {}%
  [\textbullet]%
% ---------------------------------------------------------------------  
% Get the multiple author set
\newcount\@authcnt
\newcount\@tmpcnt\@tmpcnt\z@

\def\@affiliation{%
  \ifnum\@tmpcnt<\@authcnt
   \global\advance\@tmpcnt1
    \raggedright \csname @auth\romannumeral\the\@tmpcnt\endcsname\hfill\\%
   \let\next\@affiliation \vskip1pt
  \else
   \let\next\relax
  \fi
\next}
	 
\newcommand{\affiliation}[1]{%
    \global\advance\@authcnt1
    \expandafter\gdef\csname @auth\romannumeral\the\@authcnt\endcsname
    {#1}}
% ---------------------------------------------------------------------
\RequirePackage{enumitem}
%\setlist{nolistsep} % Uncomment to remove spacing between items in lists (enumerate, itemize)
% ---------------------------------------------------------------------
% Remove brackets from numbering in List of References
\renewcommand{\@biblabel}[1]{\bfseries\color{color1}\textsuperscript{[#1]}}
%\setlength{\bibitemsep}{0cm}
% ---------------------------------------------------------------------
\newcommand{\PaperTitle}[1]{\def\@PaperTitle{#1}}
\newcommand{\Archive}[1]{\def\@Archive{#1}}
\newcommand{\Authors}[1]{\def\@Authors{#1}}
\newcommand{\JournalInfo}[1]{\def\@JournalInfo{#1}}
\newcommand{\Abstract}[1]{\def\@Abstract{#1}}
\newcommand{\Keywords}[1]{\def\@Keywords{#1}}
% ---------------------------------------------------------------------
\renewcommand\tableofcontents{\@starttoc{toc}}
\renewcommand{\@maketitle}{%
\thispagestyle{empty}%
\vskip-36pt%
%{\raggedleft\small\itshape\@JournalInfo\par}%
%\vskip20pt%
{\raggedright\huge\bfseries\sffamily\@PaperTitle\par}%
\vskip10pt%
{\raggedright\sffamily\large\selectfont\@Authors\par}
\vskip18pt%
\noindent%
\fcolorbox{color1}{white}{%
\parbox[t]{\textwidth-2\fboxsep-2\fboxrule}{\centering%
\colorbox{color2!10}{%
\parbox[t]{\textwidth-4\fboxsep-4\fboxrule}{%
\ifx\@Keywords\@empty%
{\small\sffamily\bfseries\abstractname}\par\@Abstract%
\else%
{\small\sffamily\bfseries\abstractname}\par\small\@Abstract\\[5pt]%
{\small\sffamily\bfseries\keywordname}\par\small\@Keywords\\[5pt]
{\small\sffamily\bfseries Contents}
\tableofcontents%
\fi}}%
\vskip5pt%
\begingroup%
\sffamily\scriptsize\@affiliation\par%
\endgroup%%
}%
}%
\vskip25pt%
}%
% ---------------------------------------------------------------------
\let\oldbibliography\thebibliography
\renewcommand{\thebibliography}[1]{%
\addcontentsline{toc}{section}{\hspace*{-\tocsep}\refname}%
\oldbibliography{#1}%
\setlength\itemsep{0pt}%
}